@@ -13,12 +13,13 @@ use App::Packager;
 our @EXPORT = qw( load_icon_images get_icon );
 
 my %icons;
+my %idef;
 
 sub _load_icon_images {
 
-    my ( $env, $pdf ) = @_;
+    my ( $env ) = @_;
 
-    my %idef =
+    %idef =
       ( mscz	    => 'builtin:MuseScore',
 	html	    => 'builtin:iRealPro',
 	sib	    => 'builtin:Sibelius',
@@ -29,10 +30,16 @@ sub _load_icon_images {
       );
 
     if ( $env->{all} ) {
-	$idef{biab} = 'builtin:BandInABox';
 	$idef{jpg}  = 'builtin:JPG';
+	$idef{jpeg} = 'builtin:JPG';
 	$idef{png}  = 'builtin:PNG';
 	$idef{pdf}  = 'builtin:PDF';
+	$idef{biab} = 'builtin:BandInABox';
+	for my $t ( qw( s m ) ) {
+	    for my $i ( 0 .. 9, 'u' ) {
+		$idef{sprintf("%sg%s", $t, $i)} = 'builtin:BandInABox';
+	    }
+	}
     }
     foreach ( keys %{ $env->{icons} } ) {
 	if ( $env->{icons}->{$_} ) {
@@ -44,29 +51,28 @@ sub _load_icon_images {
     }
     $idef{' fallback'} = 'builtin:Document' if $env->{all};
 
-    while ( my ( $type, $file ) = each %idef ) {
+    return;
+}
+
+sub get_icon {
+    my ( $env, $pdf, $ext ) = ( $_[0], $_[1], lc($_[2]) );
+
+    # Return the image object if we already have it.
+    return $icons{$ext} if exists $icons{$ext};
+
+    # Note. There's some work to do.
+    _load_icon_images($env) unless %idef;
+
+    my ( $type, $file ) = ( $ext, $idef{$ext} );
+    if ( $file ) {
 	if ( $file =~ /^builtin:(.*)/ ) {
 	    my $data
 	      = eval( "require " . __PACKAGE__ . "::" . $1 . ";" .
 		      "\\" . __PACKAGE__ . "::" . $1 . "::" . "icon();" );
 	    croak("No icon data for $file") unless $data;
 	    open( my $fd, '<:raw', $data );
-	    my $p = $pdf->image_png($fd);
+	    $icons{$type} = $pdf->image_png($fd);
 	    close($fd);
-	    $icons{$type} = $p;
-	    if ( $type eq 'jpg' ) {
-		$icons{jpeg} = $p;
-	    }
-	    elsif ( $type eq 'jpeg' ) {
-		$icons{jpg} = $p;
-	    }
-	    elsif ( $type eq 'biab' ) {
-		for my $t ( qw( s m ) ) {
-		    for my $i ( 0 .. 9, 'u' ) {
-			$icons{sprintf("%sg%s", $t, $i)} = $p;
-		    }
-		}
-	    }
 	}
 	else {
 	    croak("$file: $!") unless -r $file;
@@ -83,22 +89,20 @@ sub _load_icon_images {
 		croak("$file: Unsupported file type");
 	    }
 	}
+	foreach ( keys %idef ) {
+	    $icons{$_} = $icons{$type} if $idef{$_} eq $file;
+	}
     }
-
-    return;
-}
-
-sub get_icon {
-    my ( $env, $pdf, $ext ) = ( $_[0], $_[1], lc($_[2]) );
-
-    _load_icon_images( $env, $pdf ) unless %icons;
-
     return $icons{$ext} if $icons{$ext};
     return $icons{' fallback'} if defined $icons{' fallback'};
     return;
 }
 
 # For testing.
-sub __icons { \%icons };
+sub __icons {
+    my $pdf = shift;
+    get_icon( undef, $pdf, $_ ) for keys %idef;
+    \%icons;
+};
 
 1;
